# Generated by Django 2.2.3 on 2019-12-03 17:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("response", "0015_improve_actions")]

    operations = [
        migrations.AlterField(
            model_name="action",
            name="created_date",
            field=models.DateTimeField(auto_now_add=True, null=True),
        )
    ]
